@@ -90,6 +90,9 @@ $cacti_version_codes = array(
 	'1.1.14' => '0101',
 	'1.1.15' => '0101',
 	'1.1.16' => '0101',
+	'1.1.17' => '0101',
+	'1.1.18' => '0101',
+	'1.1.19' => '0101',
 );
 
 $messages = array(
@@ -177,6 +180,12 @@ $messages = array(
 	34 => array(
 		'message' => __('Unable to Change Device for Data Query based Graphs.'),
 		'type' => 'error'),
+	'clog_invalid' => array(
+		'message' => __('Log file specified is not a Cacti log or archive file.'),
+		'type' => 'info'),
+	'clog_remove' => array(
+		'message' => __('Log file specified was Cacti archive file and was removed.'),
+		'type' => 'info'),
 	'clog_purged' => array(
 		'message' => __('Cacti Log purged successfully'),
 		'type' => 'info'),
@@ -545,6 +554,27 @@ $heartbeats = array(
 	86400 => __('1 Day')
 );
 
+$timespans = array(
+	3600     => __('%d Hour', 1),
+	7200     => __('%d Hours', 2),
+	14400    => __('%d Hours', 4),
+	21600    => __('%d Hours', 6),
+	43200    => __('%d Hours', 12),
+	86400    => __('%d Day', 1),
+	172800   => __('%d Days', 2),
+	345600   => __('%d Days', 4),
+	604800   => __('%d Week', 1),
+	1209600  => __('%d Weeks', 2),
+	1814400  => __('%d Weeks', 3),
+	2618784  => __('%d Month', 1),
+	5237568  => __('%d Months', 2),
+	7856352  => __('%d Months', 3),
+	10475136 => __('%d Months', 4),
+	15712704 => __('%d Months', 6),
+	31536000 => __('%d Year', 1),
+	63072000 => __('%d Years', 2)
+);
+
 $poller_intervals = array(
 	10  => __('Every %d Seconds', 10),
 	15  => __('Every %d Seconds', 15),
@@ -864,6 +894,7 @@ $page_refresh_interval = array(
 $user_auth_realms = array(
 	8    => __('Console Access'),
 	7    => __('View Graphs'),
+	25   => __('Realtime Graphs'),
 	20   => __('Update Profile'),
 	24   => __('External Links'),
 
@@ -897,7 +928,7 @@ $user_auth_realms = array(
 );
 
 $user_auth_roles = array(
-	'Normal User'            => array(7, 19, 20, 22, 24),
+	'Normal User'            => array(7, 19, 20, 22, 24, 25),
 	'Template Editor'        => array(8, 2, 9, 10, 11, 12, 13, 14, 16, 17),
 	'General Administration' => array(8, 3, 4, 5, 23, 1043),
 	'System Administration'  => array(8, 15, 1, 18, 21, 101)
@@ -922,7 +953,7 @@ $user_auth_realm_filenames = array(
 	'graph_templates_inputs.php' => 10,
 	'graph_templates_items.php' => 10,
 	'graph_view.php' => 7,
-	'graph_realtime.php' => 7,
+	'graph_realtime.php' => 25,
 	'graphs.php' => 5,
 	'graphs_items.php' => 5,
 	'graphs_new.php' => 5,
@@ -1466,6 +1497,12 @@ $automation_frequencies = array(
 	'40320'    => __('Every %d Weeks', 4)
 );
 
+$logrotate_frequency = array(
+	'1'  => __('Daily'),
+	'7'  => __('Weekly'),
+	'30' => __('Monthly')
+);
+
 $no_session_write = array(
 	'graph_xport.php',
 	'graph_image.php',
